pyxmpp._xmlextra

Package pyxmpp :: Module _xmlextra |
[hide private]

# Module _xmlextra

Special libxml2 extensions for PyXMPP internal use.

Functions | [hide private]
remove_ns(...) |
replace_ns(...) |
sax_reader_new(...) |

Variables | [hide private]
| __package__ = `None` hash(x)
| __revision__ = ``'``$Id: xmlextra.c,v 1.6 2004/10/04 13:01:18 jajc``...``

Imports: error

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: xmlextra.c,v 1.6 2004/10/04 13:01:18 jajcus Exp $'